@@ -16,12 +16,7 @@ where
         self.buf.write_all(b"DELETE FROM ")?;
         self.write_table_info(main_table)?;
         self.buf.write_all(b" WHERE ")?;
-        self.insert_ident(
-            &Ciboulette2PgTableField::new(main_table.id().get_ident().clone(), None, None),
-            &main_table,
-        )?;
-        self.buf.write_all(b" = ")?;
-        self.insert_params(Ciboulette2PgValue::from(query.resource_id()), &main_table)?;
+        self.compare_pkey(&main_table, query.resource_id())?;
         Ok(())
     }
 }
