@@ -6,8 +6,8 @@ mod select_success;
 pub(crate) async fn test_select<'store>(
     pool: &mut sqlx::PgPool,
     query_end: &str,
-    _name: &str,
-    _data: &BTreeMap<String, Vec<Uuid>>,
+    name: &str,
+    _data: &BTreeMap<String, Vec<String>>,
 ) -> Vec<sqlx::postgres::PgRow> {
     let ciboulette_store = gen_bag();
     let table_store = gen_table_store(&ciboulette_store);
@@ -21,8 +21,8 @@ pub(crate) async fn test_select<'store>(
         Ciboulette2PgBuilder::gen_select(&ciboulette_store, &table_store, &ciboulette_request)
             .unwrap();
     let (query, args) = builder.build().unwrap();
-    println!(
-        "{}",
+    insta::assert_snapshot!(
+        format!("{}_select_query", name),
         sqlformat::format(
             query.as_str(),
             &sqlformat::QueryParams::None,
